#
# spec file for package tuba
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         appname dev.geopjr.Tuba
Name:           tuba
Version:        0.9.1
Release:        1.2
Summary:        Browse the Fediverse
License:        GPL-3.0-only
URL:            https://github.com/GeopJr/Tuba
Source0:        %{url}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  appstream-glib
BuildRequires:  cmake
BuildRequires:  desktop-file-utils
BuildRequires:  hicolor-icon-theme
BuildRequires:  meson >= 0.56
BuildRequires:  pkgconfig
BuildRequires:  vala >= 0.48
BuildRequires:  pkgconfig(clapper-0.0)
BuildRequires:  pkgconfig(gee-0.8) >= 0.8.5
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-base-1.0)
BuildRequires:  pkgconfig(gtksourceview-5)
BuildRequires:  pkgconfig(icu-uc)
BuildRequires:  pkgconfig(json-glib-1.0) >= 1.4.4
BuildRequires:  pkgconfig(libadwaita-1) >= 1.5
BuildRequires:  pkgconfig(libsecret-1) >= 0.20
BuildRequires:  pkgconfig(libsoup-3.0) >= 3.0.0
BuildRequires:  pkgconfig(libspelling-1)
BuildRequires:  pkgconfig(libwebp)
BuildRequires:  pkgconfig(libxml-2.0) >= 2.9.10

%lang_package

%description
%{summary}.

%prep
%autosetup -n Tuba-%{version}

%build
%meson \
  -Ddevel=false \
  -Ddistro=true \
  -Dclapper=true
%meson_build

%install
%meson_install
%find_lang %{appname}

%check
%meson_test

%files
%license LICENSE
%doc CODE_OF_CONDUCT.md README.md
%{_bindir}/%{appname}
%{_datadir}/applications/%{appname}.desktop
%{_datadir}/glib-2.0/schemas/dev.geopjr.Tuba.gschema.xml
%{_datadir}/gtksourceview-5/language-specs/fedi-*.lang
%{_datadir}/gtksourceview-5/styles/fedi*
%{_iconsdir}/hicolor/scalable/apps/%{appname}.svg
%{_iconsdir}/hicolor/symbolic/apps/%{appname}-symbolic.svg
%{_mandir}/man?/%{appname}.?%{?ext_man}
%{_datadir}/metainfo/%{appname}.metainfo.xml

%files lang -f %{appname}.lang

%changelog
* Mon Dec 30 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 0.9.1:
  * Chuckya support to the bubble timelines
  * Decreased new posts queue prepend scroll threshold
  * Enabled muting threads when the active user is mentioned instead of only
    when they are the author
  * Some filter rows being invisible due to markup
  * Default FediWrapped style being TRANSPARENT instead of WINDOW
  * Reschedule calendar month not being set correctly
  * Opening URIs on scripted exits not working due to making these functions async
  * Visual glitches and performance issues caused by the clamp and styling in
    timelines by switching to breakpoints
* Tue Dec 17 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 0.9.0:
  * Audio Visualizer
  * Focus Picker
  * Scheduled Posts
  * Draft Posts
  * Bold search query in results
  * Mute expiration and notification hiding switch
  * Verified Authors section on preview cards
  * Link discussion timelines on explore tab news
  * Accent colors and other GNOME 47 changes
  * Numeric style for counters
  * Adw.Spinners
  * Attachment thumbnail in alt text dialog
  * Custom picture widget that can display thumbnails at their defined focus position
  * tuba://share
  * Removed the pre 0.8 cache cleaner
  * Muting your own posts
  * Copy attachment on CtrlC in the Media Viewer
  * Auto-fill author button in Advanced Search Dialog
  * Hashtag extracting from the end of a post to a separate section
  * Removed GL renderer preference
  * Poll animations
  * Poll show and refresh results buttons
  * Full emoji reaction and stats support when possible
  * Opt-in anonymous preference popularity analytics
  * Improved the profile posts, replies, media filter UX
  * Use TextView for the alt text dialog
  * Sync post language and spellchecker language
  * #FediWrapped
  * Account suggestions for new fediverse users
  * Clean up timelines when blocking / muting accounts
  * Moved accounts note
  * Dedicated quote button when appropriate
  * Viewing which ones of the people you follow also follow an account
  * Refreshing outdated profile info on cached users
  * Placing favorite lists to the sidebar
  * Simpler UX for list member removals
  * Bubble timeline on supported backends
  * Moved notification policy settings to the notification view settings dialog
  * Hide window controls from the Media Viewer to avoid accidentally closing Tuba
  * Many accessibility improvements
  * Account birthday style
  * Thread root post refresh on load
  * Removed timeline refreshing on network change
  * Avatar and Header alt text viewing and editing on supported backends
  * Improved UI of the New Account Dialog to better match the HIG
  * Handle status notification type
  * Handle moderation_warning notification type
  * Window icon as a fallback
  * Alt text publishing on Akkoma
  * Dialog titles not following the HIG
  * Jarring Media Viewer scale animation states
  * Completion providers returning incorrect results due to the prefix in some backends
  * Crashes due to custom widgets types not being available sometimes
  * Floating button area being unclickable and unscrollable
  * Headerbar having a big minimum width
  * Use UriLauncher when appropriate
  * Utility dialogs headerbar UX not following the HIG
  * List creation and editing on Akkoma
  * Media Viewer auto-hide timeout match Gtk.Video's
  * Filter creation and editing on GoToSocial
  * Timestamp tooltip text format not being converted to the local timezone from UTC
  * RTL versions of icons not being set or missing
* Tue Sep 10 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 0.8.4:
  * Segfault when closing the mediaviewer before the spinner timeout finishes
* Mon Aug 26 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 0.8.3:
  * Caching support for Clapper 0.8
  * On-disk cache clearing for manually downloaded media attachments on
    non-Clapper
  * Temporary mechanism to delete leftover cache folders from when
    Tootle's caching was in use
  * Missing translation context
  * Do not use MPRIS for GIFV on Clapper
  * Do not create unnecessary Gst elements on Clapper
  * Do not explicitly set autoplay for GIFV on Clapper
  * Do not set videos to paused if they are actually stopped on Clapper
  * Missing tooltips
  * Redesigned Search view's empty state
  * Focus ring not matching the widget
  * Alt window headerbar being taller than expected
  * Only show Media Viewer 'loading' spinners after 1s to avoid
    unnecessary friction on fast internet connections
  * Removed back animation when going back home
  * Own posts being hidden if caught in a filter
* Thu Jul 18 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 0.8.2:
  * Better MPRIS Clapper support
  * Clapper GIF looping
  * Hid Clapper's media controls for GIFs
  * Blur + greyscale + no cache for admin reports' attachment to protect them
    from illegal and disturbing media
  * Status name button tooltip
  * Signed int multiplication overflow
  * Mini-profile padding
  * Profile cover focus ring
  * Media Viewer crashes due to Graphics Offload by setting it to false by
    default until GTK 4.16
  * Websocket events being unnecessarily url decoded
  * Random crash when navigating back
  * Notification count not being updated after network reconnection
  * Admin report dialogs not being able to close without taking an action
- switch to meson build system
* Sun Jun 23 2024 Richard Rahl <rrahl0@disroot.org>
- update to version 0.8.1:
  * gsettings options to disable graphics offload in runtime, in case it crashes
  * Media Viewer gestures requiring an extra click sometimes to work
  * Media Viewer images not being marked as loaded
* Sat Jun 22 2024 Richard Rahl <rrahl0@disroot.org>
- update to version 0.8.0:
  * Admin Dashboard
  * Advanced Search Dialog
  * Ability to dim non-trivial notifications like favorites and boosts
  * Notification clearing
  * Notification filtering
  * Notification requests
  * In-app proxy settings
  * Optional Clapper support
  * Replaced the Media Viewer headerbar with a floating button on fullscreen
  * Reactive relationship updates
  * 'Replying to older post' reminder switch in settings
  * Preview card redesign into a vertical layout
  * Use different icons per view for their empty state status
  * New account window settings
  * Crossed out boost icon when disabled
  * Custom aria labels that contain a summary of the containers
  * Set default poll expiration date to 1 day if available
  * Link opening optimizations
  * Open web+ap links in-app
  * Notify about new sign ups and new reports for admins
  * Notify about severed relationships
  * Post translations when possible
  * Mini profiles on avatar click
  * Profile notes
  * Blocked-by relationship status
  * Network monitoring and graceful recover
  * Profile fields redesign
  * Media Viewer videos will remember the last volume set between restarts
  * GraphicsOffload for Media Viewer videos
  * Profile fields custom emojis
  * In-reply indicator
  * Account Switcher rows using markup
  * Bundle icons that are either missing or have lost their meaning in Breeze/Yaru
  * Snap CI for x86-64 and GNOME 46 sdk
  * Multiple bulk-relationship requests due to multiple content-changed triggers
  * Duplicate posts in 'Home' due to race conditions
  * High-contrast theme borders on profile fields
  * Libsoup not respecting cache and instead re-downloading emojis when it shouldn't
  * Refactored the Custom Emoji Picker to use custom widgets
  * Completion provider capturing
  * Removed all optional chaining instances
  * Scale revealer measuring
  * Focus grabbing of links in labels
  * Segfault when closing the composer quickly due to a dispose hack
  * Min width due to strict headerbar centering policy
  * Segfault when inspecting labels with widgets due to infinite loop of a property
  * Singular and plural versions of some counters
  * Accessibility of icons
  * Better aria labels for dates
  * Missing tooltips
  * Accessibility of containers
  * Accessibility of custom widgets
  * Lower height request so it fits with OSK
  * Stricter resolvable link detection rules
  * Stricter hashtag url matching when clicking a link
  * Many random segfaults when going back caused by a disposing hack
  * Hiding inline quotes when there's no actual quote and the class wasn't sanitized
  * Composer highlighting hashtags accepting invalid characters
  * Composer highlighting being too loose on whole word matching
  * Horizontal swiping on the Media Viewer
  * Crash when opening the composer while the instance doesn't have custom emojis due to optional chaining
  * Some strings not being marked for translations
  * Other bug and memory leak fixes
* Sun Apr 21 2024 Richard Rahl <rrahl0@disroot.org>
- initial packaging
